"""
    GIPS API

    Allow clients to use GIPS through APIs.  # noqa: E501

    The version of the OpenAPI document: 0.1.0
    Contact: api@factset.com
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401
import sys  # noqa: F401
from multiprocessing.pool import ApplyResult
import typing

from fds.sdk.GIPS.api_client import ApiClient, Endpoint as _Endpoint
from fds.sdk.GIPS.model_utils import (  # noqa: F401
    check_allowed_values,
    check_validations,
    date,
    datetime,
    file_type,
    none_type,
    validate_and_convert_types
)
from fds.sdk.GIPS.exceptions import ApiException
from fds.sdk.GIPS.model.api_client_error_response import APIClientErrorResponse
from fds.sdk.GIPS.model.account_directories_root import AccountDirectoriesRoot
from fds.sdk.GIPS.model.currency_root import CurrencyRoot
from fds.sdk.GIPS.model.gips_views_root import GIPSViewsRoot





class GIPSLookupsApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

        self.gips_get_accounts_endpoint = _Endpoint(
            settings={
                'response_type': (
                  { 200: (AccountDirectoriesRoot,), 404: (APIClientErrorResponse,),  },
                  None
                ),
                'auth': [
                    'FactSetApiKey',
                    'FactSetOAuth2'
                ],
                'endpoint_path': '/accounts/{path}',
                'operation_id': 'gips_get_accounts',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'path',
                ],
                'required': [
                    'path',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'path':
                        (str,),
                },
                'attribute_map': {
                    'path': 'path',
                },
                'location_map': {
                    'path': 'path',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )

        self.gips_get_currencies_endpoint = _Endpoint(
            settings={
                'response_type': (
                  { 200: (CurrencyRoot,),  },
                  None
                ),
                'auth': [
                    'FactSetApiKey',
                    'FactSetOAuth2'
                ],
                'endpoint_path': '/currencies',
                'operation_id': 'gips_get_currencies',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                ],
                'required': [],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                },
                'attribute_map': {
                },
                'location_map': {
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )

        self.gips_get_views_endpoint = _Endpoint(
            settings={
                'response_type': (
                  { 200: (GIPSViewsRoot,),  },
                  None
                ),
                'auth': [
                    'FactSetApiKey',
                    'FactSetOAuth2'
                ],
                'endpoint_path': '/views',
                'operation_id': 'gips_get_views',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                ],
                'required': [],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                },
                'attribute_map': {
                },
                'location_map': {
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )


    @staticmethod
    def apply_kwargs_defaults(kwargs, return_http_data_only, async_req):
        kwargs["async_req"] = async_req
        kwargs["_return_http_data_only"] = return_http_data_only
        kwargs["_preload_content"] = kwargs.get("_preload_content", True)
        kwargs["_request_timeout"] = kwargs.get("_request_timeout", None)
        kwargs["_check_input_type"] = kwargs.get("_check_input_type", True)
        kwargs["_check_return_type"] = kwargs.get("_check_return_type", True)
        kwargs["_spec_property_naming"] = kwargs.get("_spec_property_naming", False)
        kwargs["_content_type"] = kwargs.get("_content_type")
        kwargs["_host_index"] = kwargs.get("_host_index")


    def gips_get_accounts(
        self,
        path,
        **kwargs
    ) -> AccountDirectoriesRoot:
        """Get accounts  # noqa: E501

        This endpoint requests all GIPS composites and sub-directories in the given directory which can be used in the GipsCalculationParameters schema. Please note that the endpoint returns all ACTMs and not all are GIPS Compliant.  # noqa: E501
        This method makes a synchronous HTTP request. Returns the http data only

        Args:
            path (str): The directory to get the accounts and sub-directories.

        Keyword Args:
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True. NOTE: if this API returns a file, it is the responsibility
                of the caller to close the file stream.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
        Returns:
            AccountDirectoriesRoot
                Response Object
        """
        self.apply_kwargs_defaults(kwargs=kwargs, return_http_data_only=True, async_req=False)
        kwargs['path'] = \
            path
        return self.gips_get_accounts_endpoint.call_with_http_info(**kwargs)

    def gips_get_accounts_with_http_info(
        self,
        path,
        **kwargs
    ) -> typing.Tuple[AccountDirectoriesRoot, int, typing.MutableMapping]:
        """Get accounts  # noqa: E501

        This endpoint requests all GIPS composites and sub-directories in the given directory which can be used in the GipsCalculationParameters schema. Please note that the endpoint returns all ACTMs and not all are GIPS Compliant.  # noqa: E501
        This method makes a synchronous HTTP request. Returns http data, http status and headers

        Args:
            path (str): The directory to get the accounts and sub-directories.

        Keyword Args:
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True. NOTE: if this API returns a file, it is the responsibility
                of the caller to close the file stream.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
        Returns:
            AccountDirectoriesRoot
                Response Object
            int
                Http Status Code
            dict
                Dictionary of the response headers
        """
        self.apply_kwargs_defaults(kwargs=kwargs, return_http_data_only=False, async_req=False)
        kwargs['path'] = \
            path
        return self.gips_get_accounts_endpoint.call_with_http_info(**kwargs)

    def gips_get_accounts_async(
        self,
        path,
        **kwargs
    ) -> "ApplyResult[AccountDirectoriesRoot]":
        """Get accounts  # noqa: E501

        This endpoint requests all GIPS composites and sub-directories in the given directory which can be used in the GipsCalculationParameters schema. Please note that the endpoint returns all ACTMs and not all are GIPS Compliant.  # noqa: E501
        This method makes a asynchronous HTTP request. Returns the http data, wrapped in ApplyResult

        Args:
            path (str): The directory to get the accounts and sub-directories.

        Keyword Args:
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True. NOTE: if this API returns a file, it is the responsibility
                of the caller to close the file stream.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
        Returns:
            ApplyResult[AccountDirectoriesRoot]
        """
        self.apply_kwargs_defaults(kwargs=kwargs, return_http_data_only=True, async_req=True)
        kwargs['path'] = \
            path
        return self.gips_get_accounts_endpoint.call_with_http_info(**kwargs)

    def gips_get_accounts_with_http_info_async(
        self,
        path,
        **kwargs
    ) -> "ApplyResult[typing.Tuple[AccountDirectoriesRoot, int, typing.MutableMapping]]":
        """Get accounts  # noqa: E501

        This endpoint requests all GIPS composites and sub-directories in the given directory which can be used in the GipsCalculationParameters schema. Please note that the endpoint returns all ACTMs and not all are GIPS Compliant.  # noqa: E501
        This method makes a asynchronous HTTP request. Returns http data, http status and headers, wrapped in ApplyResult

        Args:
            path (str): The directory to get the accounts and sub-directories.

        Keyword Args:
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True. NOTE: if this API returns a file, it is the responsibility
                of the caller to close the file stream.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
        Returns:
            ApplyResult[(AccountDirectoriesRoot, int, typing.Dict)]
        """
        self.apply_kwargs_defaults(kwargs=kwargs, return_http_data_only=False, async_req=True)
        kwargs['path'] = \
            path
        return self.gips_get_accounts_endpoint.call_with_http_info(**kwargs)


    def gips_get_currencies(
        self,
        **kwargs
    ) -> CurrencyRoot:
        """Get currencies  # noqa: E501

        This endpoint lists all the supported currencies that can be used in the GipsCalculationParameters schema.  # noqa: E501
        This method makes a synchronous HTTP request. Returns the http data only


        Keyword Args:
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True. NOTE: if this API returns a file, it is the responsibility
                of the caller to close the file stream.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
        Returns:
            CurrencyRoot
                Response Object
        """
        self.apply_kwargs_defaults(kwargs=kwargs, return_http_data_only=True, async_req=False)
        return self.gips_get_currencies_endpoint.call_with_http_info(**kwargs)

    def gips_get_currencies_with_http_info(
        self,
        **kwargs
    ) -> typing.Tuple[CurrencyRoot, int, typing.MutableMapping]:
        """Get currencies  # noqa: E501

        This endpoint lists all the supported currencies that can be used in the GipsCalculationParameters schema.  # noqa: E501
        This method makes a synchronous HTTP request. Returns http data, http status and headers


        Keyword Args:
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True. NOTE: if this API returns a file, it is the responsibility
                of the caller to close the file stream.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
        Returns:
            CurrencyRoot
                Response Object
            int
                Http Status Code
            dict
                Dictionary of the response headers
        """
        self.apply_kwargs_defaults(kwargs=kwargs, return_http_data_only=False, async_req=False)
        return self.gips_get_currencies_endpoint.call_with_http_info(**kwargs)

    def gips_get_currencies_async(
        self,
        **kwargs
    ) -> "ApplyResult[CurrencyRoot]":
        """Get currencies  # noqa: E501

        This endpoint lists all the supported currencies that can be used in the GipsCalculationParameters schema.  # noqa: E501
        This method makes a asynchronous HTTP request. Returns the http data, wrapped in ApplyResult


        Keyword Args:
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True. NOTE: if this API returns a file, it is the responsibility
                of the caller to close the file stream.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
        Returns:
            ApplyResult[CurrencyRoot]
        """
        self.apply_kwargs_defaults(kwargs=kwargs, return_http_data_only=True, async_req=True)
        return self.gips_get_currencies_endpoint.call_with_http_info(**kwargs)

    def gips_get_currencies_with_http_info_async(
        self,
        **kwargs
    ) -> "ApplyResult[typing.Tuple[CurrencyRoot, int, typing.MutableMapping]]":
        """Get currencies  # noqa: E501

        This endpoint lists all the supported currencies that can be used in the GipsCalculationParameters schema.  # noqa: E501
        This method makes a asynchronous HTTP request. Returns http data, http status and headers, wrapped in ApplyResult


        Keyword Args:
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True. NOTE: if this API returns a file, it is the responsibility
                of the caller to close the file stream.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
        Returns:
            ApplyResult[(CurrencyRoot, int, typing.Dict)]
        """
        self.apply_kwargs_defaults(kwargs=kwargs, return_http_data_only=False, async_req=True)
        return self.gips_get_currencies_endpoint.call_with_http_info(**kwargs)


    def gips_get_views(
        self,
        **kwargs
    ) -> GIPSViewsRoot:
        """Get views  # noqa: E501

        This endpoint lists all the views that can be used in the GipsCalculationParameters schema.  # noqa: E501
        This method makes a synchronous HTTP request. Returns the http data only


        Keyword Args:
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True. NOTE: if this API returns a file, it is the responsibility
                of the caller to close the file stream.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
        Returns:
            GIPSViewsRoot
                Response Object
        """
        self.apply_kwargs_defaults(kwargs=kwargs, return_http_data_only=True, async_req=False)
        return self.gips_get_views_endpoint.call_with_http_info(**kwargs)

    def gips_get_views_with_http_info(
        self,
        **kwargs
    ) -> typing.Tuple[GIPSViewsRoot, int, typing.MutableMapping]:
        """Get views  # noqa: E501

        This endpoint lists all the views that can be used in the GipsCalculationParameters schema.  # noqa: E501
        This method makes a synchronous HTTP request. Returns http data, http status and headers


        Keyword Args:
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True. NOTE: if this API returns a file, it is the responsibility
                of the caller to close the file stream.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
        Returns:
            GIPSViewsRoot
                Response Object
            int
                Http Status Code
            dict
                Dictionary of the response headers
        """
        self.apply_kwargs_defaults(kwargs=kwargs, return_http_data_only=False, async_req=False)
        return self.gips_get_views_endpoint.call_with_http_info(**kwargs)

    def gips_get_views_async(
        self,
        **kwargs
    ) -> "ApplyResult[GIPSViewsRoot]":
        """Get views  # noqa: E501

        This endpoint lists all the views that can be used in the GipsCalculationParameters schema.  # noqa: E501
        This method makes a asynchronous HTTP request. Returns the http data, wrapped in ApplyResult


        Keyword Args:
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True. NOTE: if this API returns a file, it is the responsibility
                of the caller to close the file stream.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
        Returns:
            ApplyResult[GIPSViewsRoot]
        """
        self.apply_kwargs_defaults(kwargs=kwargs, return_http_data_only=True, async_req=True)
        return self.gips_get_views_endpoint.call_with_http_info(**kwargs)

    def gips_get_views_with_http_info_async(
        self,
        **kwargs
    ) -> "ApplyResult[typing.Tuple[GIPSViewsRoot, int, typing.MutableMapping]]":
        """Get views  # noqa: E501

        This endpoint lists all the views that can be used in the GipsCalculationParameters schema.  # noqa: E501
        This method makes a asynchronous HTTP request. Returns http data, http status and headers, wrapped in ApplyResult


        Keyword Args:
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True. NOTE: if this API returns a file, it is the responsibility
                of the caller to close the file stream.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
        Returns:
            ApplyResult[(GIPSViewsRoot, int, typing.Dict)]
        """
        self.apply_kwargs_defaults(kwargs=kwargs, return_http_data_only=False, async_req=True)
        return self.gips_get_views_endpoint.call_with_http_info(**kwargs)





"""
    GIPS API

    Allow clients to use GIPS through APIs.  # noqa: E501

    The version of the OpenAPI document: 0.1.0
    Contact: api@factset.com
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401
import sys  # noqa: F401
from multiprocessing.pool import ApplyResult
import typing

from fds.sdk.GIPS.api_client import ApiClient, Endpoint as _Endpoint
from fds.sdk.GIPS.model_utils import (  # noqa: F401
    check_allowed_values,
    check_validations,
    date,
    datetime,
    file_type,
    none_type,
    validate_and_convert_types
)
from fds.sdk.GIPS.exceptions import ApiException
from fds.sdk.GIPS.model.api_client_error_response import APIClientErrorResponse
from fds.sdk.GIPS.model.calculation_status_root import CalculationStatusRoot
from fds.sdk.GIPS.model.calculations_summary_root import CalculationsSummaryRoot
from fds.sdk.GIPS.model.fact_set_protobuf_stach_v3_stach_v3_table import FactSetProtobufStachV3StachV3Table
from fds.sdk.GIPS.model.gips_calculation_parameters_root import GIPSCalculationParametersRoot





class GIPSCalculationsApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

        self.cancel_calculation_by_id_endpoint = _Endpoint(
            settings={
                'response_type': None,
                'auth': [
                    'FactSetApiKey',
                    'FactSetOAuth2'
                ],
                'endpoint_path': '/calculations/{id}',
                'operation_id': 'cancel_calculation_by_id',
                'http_method': 'DELETE',
                'servers': None,
            },
            params_map={
                'all': [
                    'id',
                ],
                'required': [
                    'id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'id':
                        (str,),
                },
                'attribute_map': {
                    'id': 'id',
                },
                'location_map': {
                    'id': 'path',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )

        self.gips_get_all_calculations_endpoint = _Endpoint(
            settings={
                'response_type': (
                  { 200: (CalculationsSummaryRoot,), 400: (APIClientErrorResponse,),  },
                  None
                ),
                'auth': [
                    'FactSetApiKey',
                    'FactSetOAuth2'
                ],
                'endpoint_path': '/calculations',
                'operation_id': 'gips_get_all_calculations',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'page_number',
                ],
                'required': [],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'page_number':
                        (int,),
                },
                'attribute_map': {
                    'page_number': 'pageNumber',
                },
                'location_map': {
                    'page_number': 'query',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )

        self.gips_get_calculation_status_by_id_endpoint = _Endpoint(
            settings={
                'response_type': (
                  { 201: (CalculationStatusRoot,), 202: (CalculationStatusRoot,), 404: (APIClientErrorResponse,),  },
                  None
                ),
                'auth': [
                    'FactSetApiKey',
                    'FactSetOAuth2'
                ],
                'endpoint_path': '/calculations/{id}/status',
                'operation_id': 'gips_get_calculation_status_by_id',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'id',
                ],
                'required': [
                    'id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'id':
                        (str,),
                },
                'attribute_map': {
                    'id': 'id',
                },
                'location_map': {
                    'id': 'path',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )

        self.gips_get_calculation_unit_result_by_id_endpoint = _Endpoint(
            settings={
                'response_type': (
                  { 200: (FactSetProtobufStachV3StachV3Table,), 404: (APIClientErrorResponse,),  },
                  None
                ),
                'auth': [
                    'FactSetApiKey',
                    'FactSetOAuth2'
                ],
                'endpoint_path': '/calculations/{id}/units/{unitId}/result',
                'operation_id': 'gips_get_calculation_unit_result_by_id',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'id',
                    'unit_id',
                ],
                'required': [
                    'id',
                    'unit_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'id':
                        (str,),
                    'unit_id':
                        (str,),
                },
                'attribute_map': {
                    'id': 'id',
                    'unit_id': 'unitId',
                },
                'location_map': {
                    'id': 'path',
                    'unit_id': 'path',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/stach.v3+json',
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )

        self.gips_post_and_calculate_endpoint = _Endpoint(
            settings={
                'response_type': (
                  { 201: (CalculationStatusRoot,), 202: (CalculationStatusRoot,), 400: (APIClientErrorResponse,), 404: (APIClientErrorResponse,), 429: (APIClientErrorResponse,),  },
                  None
                ),
                'auth': [
                    'FactSetApiKey',
                    'FactSetOAuth2'
                ],
                'endpoint_path': '/calculations',
                'operation_id': 'gips_post_and_calculate',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'x_fact_set_api_long_running_deadline',
                    'cache_control',
                    'gips_calculation_parameters_root',
                ],
                'required': [],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'x_fact_set_api_long_running_deadline':
                        (int,),
                    'cache_control':
                        (str,),
                    'gips_calculation_parameters_root':
                        (GIPSCalculationParametersRoot,),
                },
                'attribute_map': {
                    'x_fact_set_api_long_running_deadline': 'X-FactSet-Api-Long-Running-Deadline',
                    'cache_control': 'Cache-Control',
                },
                'location_map': {
                    'x_fact_set_api_long_running_deadline': 'header',
                    'cache_control': 'header',
                    'gips_calculation_parameters_root': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client
        )


    @staticmethod
    def apply_kwargs_defaults(kwargs, return_http_data_only, async_req):
        kwargs["async_req"] = async_req
        kwargs["_return_http_data_only"] = return_http_data_only
        kwargs["_preload_content"] = kwargs.get("_preload_content", True)
        kwargs["_request_timeout"] = kwargs.get("_request_timeout", None)
        kwargs["_check_input_type"] = kwargs.get("_check_input_type", True)
        kwargs["_check_return_type"] = kwargs.get("_check_return_type", True)
        kwargs["_spec_property_naming"] = kwargs.get("_spec_property_naming", False)
        kwargs["_content_type"] = kwargs.get("_content_type")
        kwargs["_host_index"] = kwargs.get("_host_index")


    def cancel_calculation_by_id(
        self,
        id,
        **kwargs
    ) -> None:
        """Cancel GIPS calculation by id  # noqa: E501

        Use this endpoint to clear calculations from the queue. Note, calculations that are already running cannot be cancelled.  # noqa: E501
        This method makes a synchronous HTTP request. Returns the http data only

        Args:
            id (str): from url, provided from the location header in the Create and Run GIPS calculation endpoint

        Keyword Args:
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True. NOTE: if this API returns a file, it is the responsibility
                of the caller to close the file stream.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
        Returns:
            None
                Response Object
        """
        self.apply_kwargs_defaults(kwargs=kwargs, return_http_data_only=True, async_req=False)
        kwargs['id'] = \
            id
        return self.cancel_calculation_by_id_endpoint.call_with_http_info(**kwargs)

    def cancel_calculation_by_id_with_http_info(
        self,
        id,
        **kwargs
    ) -> typing.Tuple[None, int, typing.MutableMapping]:
        """Cancel GIPS calculation by id  # noqa: E501

        Use this endpoint to clear calculations from the queue. Note, calculations that are already running cannot be cancelled.  # noqa: E501
        This method makes a synchronous HTTP request. Returns http data, http status and headers

        Args:
            id (str): from url, provided from the location header in the Create and Run GIPS calculation endpoint

        Keyword Args:
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True. NOTE: if this API returns a file, it is the responsibility
                of the caller to close the file stream.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
        Returns:
            None
                Response Object
            int
                Http Status Code
            dict
                Dictionary of the response headers
        """
        self.apply_kwargs_defaults(kwargs=kwargs, return_http_data_only=False, async_req=False)
        kwargs['id'] = \
            id
        return self.cancel_calculation_by_id_endpoint.call_with_http_info(**kwargs)

    def cancel_calculation_by_id_async(
        self,
        id,
        **kwargs
    ) -> "ApplyResult[None]":
        """Cancel GIPS calculation by id  # noqa: E501

        Use this endpoint to clear calculations from the queue. Note, calculations that are already running cannot be cancelled.  # noqa: E501
        This method makes a asynchronous HTTP request. Returns the http data, wrapped in ApplyResult

        Args:
            id (str): from url, provided from the location header in the Create and Run GIPS calculation endpoint

        Keyword Args:
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True. NOTE: if this API returns a file, it is the responsibility
                of the caller to close the file stream.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
        Returns:
            ApplyResult[None]
        """
        self.apply_kwargs_defaults(kwargs=kwargs, return_http_data_only=True, async_req=True)
        kwargs['id'] = \
            id
        return self.cancel_calculation_by_id_endpoint.call_with_http_info(**kwargs)

    def cancel_calculation_by_id_with_http_info_async(
        self,
        id,
        **kwargs
    ) -> "ApplyResult[typing.Tuple[None, int, typing.MutableMapping]]":
        """Cancel GIPS calculation by id  # noqa: E501

        Use this endpoint to clear calculations from the queue. Note, calculations that are already running cannot be cancelled.  # noqa: E501
        This method makes a asynchronous HTTP request. Returns http data, http status and headers, wrapped in ApplyResult

        Args:
            id (str): from url, provided from the location header in the Create and Run GIPS calculation endpoint

        Keyword Args:
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True. NOTE: if this API returns a file, it is the responsibility
                of the caller to close the file stream.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
        Returns:
            ApplyResult[(None, int, typing.Dict)]
        """
        self.apply_kwargs_defaults(kwargs=kwargs, return_http_data_only=False, async_req=True)
        kwargs['id'] = \
            id
        return self.cancel_calculation_by_id_endpoint.call_with_http_info(**kwargs)


    def gips_get_all_calculations(
        self,
        **kwargs
    ) -> CalculationsSummaryRoot:
        """Get all calculations  # noqa: E501

        This endpoints returns all calculation requests.  # noqa: E501
        This method makes a synchronous HTTP request. Returns the http data only


        Keyword Args:
            page_number (int): Page number to be viewed. [optional] if omitted the server will use the default value of 1
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True. NOTE: if this API returns a file, it is the responsibility
                of the caller to close the file stream.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
        Returns:
            CalculationsSummaryRoot
                Response Object
        """
        self.apply_kwargs_defaults(kwargs=kwargs, return_http_data_only=True, async_req=False)
        return self.gips_get_all_calculations_endpoint.call_with_http_info(**kwargs)

    def gips_get_all_calculations_with_http_info(
        self,
        **kwargs
    ) -> typing.Tuple[CalculationsSummaryRoot, int, typing.MutableMapping]:
        """Get all calculations  # noqa: E501

        This endpoints returns all calculation requests.  # noqa: E501
        This method makes a synchronous HTTP request. Returns http data, http status and headers


        Keyword Args:
            page_number (int): Page number to be viewed. [optional] if omitted the server will use the default value of 1
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True. NOTE: if this API returns a file, it is the responsibility
                of the caller to close the file stream.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
        Returns:
            CalculationsSummaryRoot
                Response Object
            int
                Http Status Code
            dict
                Dictionary of the response headers
        """
        self.apply_kwargs_defaults(kwargs=kwargs, return_http_data_only=False, async_req=False)
        return self.gips_get_all_calculations_endpoint.call_with_http_info(**kwargs)

    def gips_get_all_calculations_async(
        self,
        **kwargs
    ) -> "ApplyResult[CalculationsSummaryRoot]":
        """Get all calculations  # noqa: E501

        This endpoints returns all calculation requests.  # noqa: E501
        This method makes a asynchronous HTTP request. Returns the http data, wrapped in ApplyResult


        Keyword Args:
            page_number (int): Page number to be viewed. [optional] if omitted the server will use the default value of 1
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True. NOTE: if this API returns a file, it is the responsibility
                of the caller to close the file stream.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
        Returns:
            ApplyResult[CalculationsSummaryRoot]
        """
        self.apply_kwargs_defaults(kwargs=kwargs, return_http_data_only=True, async_req=True)
        return self.gips_get_all_calculations_endpoint.call_with_http_info(**kwargs)

    def gips_get_all_calculations_with_http_info_async(
        self,
        **kwargs
    ) -> "ApplyResult[typing.Tuple[CalculationsSummaryRoot, int, typing.MutableMapping]]":
        """Get all calculations  # noqa: E501

        This endpoints returns all calculation requests.  # noqa: E501
        This method makes a asynchronous HTTP request. Returns http data, http status and headers, wrapped in ApplyResult


        Keyword Args:
            page_number (int): Page number to be viewed. [optional] if omitted the server will use the default value of 1
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True. NOTE: if this API returns a file, it is the responsibility
                of the caller to close the file stream.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
        Returns:
            ApplyResult[(CalculationsSummaryRoot, int, typing.Dict)]
        """
        self.apply_kwargs_defaults(kwargs=kwargs, return_http_data_only=False, async_req=True)
        return self.gips_get_all_calculations_endpoint.call_with_http_info(**kwargs)


    def gips_get_calculation_status_by_id(
        self,
        id,
        **kwargs
    ) -> CalculationStatusRoot:
        """Get GIPS calculation status by id  # noqa: E501

        This is the endpoint to check on the progress of a previously requested calculation.  If the calculation has finished computing, the location header will point to the result url.  # noqa: E501
        This method makes a synchronous HTTP request. Returns the http data only

        Args:
            id (str): from url, provided from the location header in the Create and Run GIPS calculation endpoint

        Keyword Args:
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True. NOTE: if this API returns a file, it is the responsibility
                of the caller to close the file stream.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
        Returns:
            CalculationStatusRoot
                Response Object
        """
        self.apply_kwargs_defaults(kwargs=kwargs, return_http_data_only=True, async_req=False)
        kwargs['id'] = \
            id
        return self.gips_get_calculation_status_by_id_endpoint.call_with_http_info(**kwargs)

    def gips_get_calculation_status_by_id_with_http_info(
        self,
        id,
        **kwargs
    ) -> typing.Tuple[CalculationStatusRoot, int, typing.MutableMapping]:
        """Get GIPS calculation status by id  # noqa: E501

        This is the endpoint to check on the progress of a previously requested calculation.  If the calculation has finished computing, the location header will point to the result url.  # noqa: E501
        This method makes a synchronous HTTP request. Returns http data, http status and headers

        Args:
            id (str): from url, provided from the location header in the Create and Run GIPS calculation endpoint

        Keyword Args:
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True. NOTE: if this API returns a file, it is the responsibility
                of the caller to close the file stream.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
        Returns:
            CalculationStatusRoot
                Response Object
            int
                Http Status Code
            dict
                Dictionary of the response headers
        """
        self.apply_kwargs_defaults(kwargs=kwargs, return_http_data_only=False, async_req=False)
        kwargs['id'] = \
            id
        return self.gips_get_calculation_status_by_id_endpoint.call_with_http_info(**kwargs)

    def gips_get_calculation_status_by_id_async(
        self,
        id,
        **kwargs
    ) -> "ApplyResult[CalculationStatusRoot]":
        """Get GIPS calculation status by id  # noqa: E501

        This is the endpoint to check on the progress of a previously requested calculation.  If the calculation has finished computing, the location header will point to the result url.  # noqa: E501
        This method makes a asynchronous HTTP request. Returns the http data, wrapped in ApplyResult

        Args:
            id (str): from url, provided from the location header in the Create and Run GIPS calculation endpoint

        Keyword Args:
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True. NOTE: if this API returns a file, it is the responsibility
                of the caller to close the file stream.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
        Returns:
            ApplyResult[CalculationStatusRoot]
        """
        self.apply_kwargs_defaults(kwargs=kwargs, return_http_data_only=True, async_req=True)
        kwargs['id'] = \
            id
        return self.gips_get_calculation_status_by_id_endpoint.call_with_http_info(**kwargs)

    def gips_get_calculation_status_by_id_with_http_info_async(
        self,
        id,
        **kwargs
    ) -> "ApplyResult[typing.Tuple[CalculationStatusRoot, int, typing.MutableMapping]]":
        """Get GIPS calculation status by id  # noqa: E501

        This is the endpoint to check on the progress of a previously requested calculation.  If the calculation has finished computing, the location header will point to the result url.  # noqa: E501
        This method makes a asynchronous HTTP request. Returns http data, http status and headers, wrapped in ApplyResult

        Args:
            id (str): from url, provided from the location header in the Create and Run GIPS calculation endpoint

        Keyword Args:
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True. NOTE: if this API returns a file, it is the responsibility
                of the caller to close the file stream.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
        Returns:
            ApplyResult[(CalculationStatusRoot, int, typing.Dict)]
        """
        self.apply_kwargs_defaults(kwargs=kwargs, return_http_data_only=False, async_req=True)
        kwargs['id'] = \
            id
        return self.gips_get_calculation_status_by_id_endpoint.call_with_http_info(**kwargs)


    def gips_get_calculation_unit_result_by_id(
        self,
        id,
        unit_id,
        **kwargs
    ) -> FactSetProtobufStachV3StachV3Table:
        """Get GIPS calculation result by id  # noqa: E501

        This is the endpoint to get the result of a previously requested calculation.  If the calculation has finished computing, the body of the response will contain the requested document in JSON.  # noqa: E501
        This method makes a synchronous HTTP request. Returns the http data only

        Args:
            id (str): from url, provided from the location header in the Get GIPS calculation status by id endpoint
            unit_id (str): from url, provided from the location header in the Get GIPS calculation status by id endpoint

        Keyword Args:
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True. NOTE: if this API returns a file, it is the responsibility
                of the caller to close the file stream.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
        Returns:
            FactSetProtobufStachV3StachV3Table
                Response Object
        """
        self.apply_kwargs_defaults(kwargs=kwargs, return_http_data_only=True, async_req=False)
        kwargs['id'] = \
            id
        kwargs['unit_id'] = \
            unit_id
        return self.gips_get_calculation_unit_result_by_id_endpoint.call_with_http_info(**kwargs)

    def gips_get_calculation_unit_result_by_id_with_http_info(
        self,
        id,
        unit_id,
        **kwargs
    ) -> typing.Tuple[FactSetProtobufStachV3StachV3Table, int, typing.MutableMapping]:
        """Get GIPS calculation result by id  # noqa: E501

        This is the endpoint to get the result of a previously requested calculation.  If the calculation has finished computing, the body of the response will contain the requested document in JSON.  # noqa: E501
        This method makes a synchronous HTTP request. Returns http data, http status and headers

        Args:
            id (str): from url, provided from the location header in the Get GIPS calculation status by id endpoint
            unit_id (str): from url, provided from the location header in the Get GIPS calculation status by id endpoint

        Keyword Args:
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True. NOTE: if this API returns a file, it is the responsibility
                of the caller to close the file stream.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
        Returns:
            FactSetProtobufStachV3StachV3Table
                Response Object
            int
                Http Status Code
            dict
                Dictionary of the response headers
        """
        self.apply_kwargs_defaults(kwargs=kwargs, return_http_data_only=False, async_req=False)
        kwargs['id'] = \
            id
        kwargs['unit_id'] = \
            unit_id
        return self.gips_get_calculation_unit_result_by_id_endpoint.call_with_http_info(**kwargs)

    def gips_get_calculation_unit_result_by_id_async(
        self,
        id,
        unit_id,
        **kwargs
    ) -> "ApplyResult[FactSetProtobufStachV3StachV3Table]":
        """Get GIPS calculation result by id  # noqa: E501

        This is the endpoint to get the result of a previously requested calculation.  If the calculation has finished computing, the body of the response will contain the requested document in JSON.  # noqa: E501
        This method makes a asynchronous HTTP request. Returns the http data, wrapped in ApplyResult

        Args:
            id (str): from url, provided from the location header in the Get GIPS calculation status by id endpoint
            unit_id (str): from url, provided from the location header in the Get GIPS calculation status by id endpoint

        Keyword Args:
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True. NOTE: if this API returns a file, it is the responsibility
                of the caller to close the file stream.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
        Returns:
            ApplyResult[FactSetProtobufStachV3StachV3Table]
        """
        self.apply_kwargs_defaults(kwargs=kwargs, return_http_data_only=True, async_req=True)
        kwargs['id'] = \
            id
        kwargs['unit_id'] = \
            unit_id
        return self.gips_get_calculation_unit_result_by_id_endpoint.call_with_http_info(**kwargs)

    def gips_get_calculation_unit_result_by_id_with_http_info_async(
        self,
        id,
        unit_id,
        **kwargs
    ) -> "ApplyResult[typing.Tuple[FactSetProtobufStachV3StachV3Table, int, typing.MutableMapping]]":
        """Get GIPS calculation result by id  # noqa: E501

        This is the endpoint to get the result of a previously requested calculation.  If the calculation has finished computing, the body of the response will contain the requested document in JSON.  # noqa: E501
        This method makes a asynchronous HTTP request. Returns http data, http status and headers, wrapped in ApplyResult

        Args:
            id (str): from url, provided from the location header in the Get GIPS calculation status by id endpoint
            unit_id (str): from url, provided from the location header in the Get GIPS calculation status by id endpoint

        Keyword Args:
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True. NOTE: if this API returns a file, it is the responsibility
                of the caller to close the file stream.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
        Returns:
            ApplyResult[(FactSetProtobufStachV3StachV3Table, int, typing.Dict)]
        """
        self.apply_kwargs_defaults(kwargs=kwargs, return_http_data_only=False, async_req=True)
        kwargs['id'] = \
            id
        kwargs['unit_id'] = \
            unit_id
        return self.gips_get_calculation_unit_result_by_id_endpoint.call_with_http_info(**kwargs)


    def gips_post_and_calculate(
        self,
        **kwargs
    ) -> CalculationStatusRoot:
        """Create and Run GIPS calculation  # noqa: E501

        This endpoint runs the GIPS calculation specified in the POST body parameters.  It can take upto 2 units.    Remarks:    * Any settings in POST body will act as a one-time override over the settings saved in the GIPS template.  Use this endpoint to trigger calculation requests.  # noqa: E501
        This method makes a synchronous HTTP request. Returns the http data only


        Keyword Args:
            x_fact_set_api_long_running_deadline (int): The number of seconds the request will wait before sending back the response. If not provided, 20 will be used as default.. [optional]
            cache_control (str): Standard HTTP header.  Accepts max-stale.. [optional]
            gips_calculation_parameters_root (GIPSCalculationParametersRoot): The request body contains the information needed to run a calculation, e.g. the GIPS composite. See the schema for more details.. [optional]
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True. NOTE: if this API returns a file, it is the responsibility
                of the caller to close the file stream.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
        Returns:
            CalculationStatusRoot
                Response Object
        """
        self.apply_kwargs_defaults(kwargs=kwargs, return_http_data_only=True, async_req=False)
        return self.gips_post_and_calculate_endpoint.call_with_http_info(**kwargs)

    def gips_post_and_calculate_with_http_info(
        self,
        **kwargs
    ) -> typing.Tuple[CalculationStatusRoot, int, typing.MutableMapping]:
        """Create and Run GIPS calculation  # noqa: E501

        This endpoint runs the GIPS calculation specified in the POST body parameters.  It can take upto 2 units.    Remarks:    * Any settings in POST body will act as a one-time override over the settings saved in the GIPS template.  Use this endpoint to trigger calculation requests.  # noqa: E501
        This method makes a synchronous HTTP request. Returns http data, http status and headers


        Keyword Args:
            x_fact_set_api_long_running_deadline (int): The number of seconds the request will wait before sending back the response. If not provided, 20 will be used as default.. [optional]
            cache_control (str): Standard HTTP header.  Accepts max-stale.. [optional]
            gips_calculation_parameters_root (GIPSCalculationParametersRoot): The request body contains the information needed to run a calculation, e.g. the GIPS composite. See the schema for more details.. [optional]
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True. NOTE: if this API returns a file, it is the responsibility
                of the caller to close the file stream.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
        Returns:
            CalculationStatusRoot
                Response Object
            int
                Http Status Code
            dict
                Dictionary of the response headers
        """
        self.apply_kwargs_defaults(kwargs=kwargs, return_http_data_only=False, async_req=False)
        return self.gips_post_and_calculate_endpoint.call_with_http_info(**kwargs)

    def gips_post_and_calculate_async(
        self,
        **kwargs
    ) -> "ApplyResult[CalculationStatusRoot]":
        """Create and Run GIPS calculation  # noqa: E501

        This endpoint runs the GIPS calculation specified in the POST body parameters.  It can take upto 2 units.    Remarks:    * Any settings in POST body will act as a one-time override over the settings saved in the GIPS template.  Use this endpoint to trigger calculation requests.  # noqa: E501
        This method makes a asynchronous HTTP request. Returns the http data, wrapped in ApplyResult


        Keyword Args:
            x_fact_set_api_long_running_deadline (int): The number of seconds the request will wait before sending back the response. If not provided, 20 will be used as default.. [optional]
            cache_control (str): Standard HTTP header.  Accepts max-stale.. [optional]
            gips_calculation_parameters_root (GIPSCalculationParametersRoot): The request body contains the information needed to run a calculation, e.g. the GIPS composite. See the schema for more details.. [optional]
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True. NOTE: if this API returns a file, it is the responsibility
                of the caller to close the file stream.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
        Returns:
            ApplyResult[CalculationStatusRoot]
        """
        self.apply_kwargs_defaults(kwargs=kwargs, return_http_data_only=True, async_req=True)
        return self.gips_post_and_calculate_endpoint.call_with_http_info(**kwargs)

    def gips_post_and_calculate_with_http_info_async(
        self,
        **kwargs
    ) -> "ApplyResult[typing.Tuple[CalculationStatusRoot, int, typing.MutableMapping]]":
        """Create and Run GIPS calculation  # noqa: E501

        This endpoint runs the GIPS calculation specified in the POST body parameters.  It can take upto 2 units.    Remarks:    * Any settings in POST body will act as a one-time override over the settings saved in the GIPS template.  Use this endpoint to trigger calculation requests.  # noqa: E501
        This method makes a asynchronous HTTP request. Returns http data, http status and headers, wrapped in ApplyResult


        Keyword Args:
            x_fact_set_api_long_running_deadline (int): The number of seconds the request will wait before sending back the response. If not provided, 20 will be used as default.. [optional]
            cache_control (str): Standard HTTP header.  Accepts max-stale.. [optional]
            gips_calculation_parameters_root (GIPSCalculationParametersRoot): The request body contains the information needed to run a calculation, e.g. the GIPS composite. See the schema for more details.. [optional]
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True. NOTE: if this API returns a file, it is the responsibility
                of the caller to close the file stream.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
        Returns:
            ApplyResult[(CalculationStatusRoot, int, typing.Dict)]
        """
        self.apply_kwargs_defaults(kwargs=kwargs, return_http_data_only=False, async_req=True)
        return self.gips_post_and_calculate_endpoint.call_with_http_info(**kwargs)





# flake8: noqa

# import all models into this package
# if you have many models here with many references from one model to another this may
# raise a RecursionError
# to avoid this, import only the models that you directly need like:
# from from fds.sdk.GIPS.model.pet import Pet
# or import this package, but before doing it, use:
# import sys
# sys.setrecursionlimit(n)

from fds.sdk.GIPS.model.api_client_error_response import APIClientErrorResponse
from fds.sdk.GIPS.model.api_error import APIError
from fds.sdk.GIPS.model.account_directories import AccountDirectories
from fds.sdk.GIPS.model.account_directories_root import AccountDirectoriesRoot
from fds.sdk.GIPS.model.calculation_status import CalculationStatus
from fds.sdk.GIPS.model.calculation_status_meta import CalculationStatusMeta
from fds.sdk.GIPS.model.calculation_status_root import CalculationStatusRoot
from fds.sdk.GIPS.model.calculation_unit_status import CalculationUnitStatus
from fds.sdk.GIPS.model.calculation_unit_status_meta import CalculationUnitStatusMeta
from fds.sdk.GIPS.model.calculations_summary import CalculationsSummary
from fds.sdk.GIPS.model.calculations_summary_root import CalculationsSummaryRoot
from fds.sdk.GIPS.model.currency import Currency
from fds.sdk.GIPS.model.currency_root import CurrencyRoot
from fds.sdk.GIPS.model.error import Error
from fds.sdk.GIPS.model.error_source import ErrorSource
from fds.sdk.GIPS.model.fact_set_protobuf_format_v1_date_time_format import FactSetProtobufFormatV1DateTimeFormat
from fds.sdk.GIPS.model.fact_set_protobuf_format_v1_fds_format_settings import FactSetProtobufFormatV1FdsFormatSettings
from fds.sdk.GIPS.model.fact_set_protobuf_format_v1_number_format import FactSetProtobufFormatV1NumberFormat
from fds.sdk.GIPS.model.fact_set_protobuf_format_v1_number_format_types_currency_standard_specifier import FactSetProtobufFormatV1NumberFormatTypesCurrencyStandardSpecifier
from fds.sdk.GIPS.model.fact_set_protobuf_format_v1_number_format_types_digits import FactSetProtobufFormatV1NumberFormatTypesDigits
from fds.sdk.GIPS.model.fact_set_protobuf_format_v1_number_format_types_exponential_standard_specifier import FactSetProtobufFormatV1NumberFormatTypesExponentialStandardSpecifier
from fds.sdk.GIPS.model.fact_set_protobuf_format_v1_number_format_types_numeric_standard_specifier import FactSetProtobufFormatV1NumberFormatTypesNumericStandardSpecifier
from fds.sdk.GIPS.model.fact_set_protobuf_format_v1_number_format_types_percent_standard_specifier import FactSetProtobufFormatV1NumberFormatTypesPercentStandardSpecifier
from fds.sdk.GIPS.model.fact_set_protobuf_format_v1_number_format_types_rounding import FactSetProtobufFormatV1NumberFormatTypesRounding
from fds.sdk.GIPS.model.fact_set_protobuf_stach_v3_metadata_item import FactSetProtobufStachV3MetadataItem
from fds.sdk.GIPS.model.fact_set_protobuf_stach_v3_sort import FactSetProtobufStachV3Sort
from fds.sdk.GIPS.model.fact_set_protobuf_stach_v3_sort_column import FactSetProtobufStachV3SortColumn
from fds.sdk.GIPS.model.fact_set_protobuf_stach_v3_stach_v3_table import FactSetProtobufStachV3StachV3Table
from fds.sdk.GIPS.model.fact_set_protobuf_stach_v3_stach_v3_table_types_column import FactSetProtobufStachV3StachV3TableTypesColumn
from fds.sdk.GIPS.model.fact_set_protobuf_stach_v3_table import FactSetProtobufStachV3Table
from fds.sdk.GIPS.model.fact_set_protobuf_stach_v3_table_types_collapsed_column_result import FactSetProtobufStachV3TableTypesCollapsedColumnResult
from fds.sdk.GIPS.model.fact_set_protobuf_stach_v3_table_types_error import FactSetProtobufStachV3TableTypesError
from fds.sdk.GIPS.model.fact_set_protobuf_stach_v3_table_types_error_types_source import FactSetProtobufStachV3TableTypesErrorTypesSource
from fds.sdk.GIPS.model.fact_set_protobuf_stach_v3_table_types_error_types_source_type_oneof_case import FactSetProtobufStachV3TableTypesErrorTypesSourceTypeOneofCase
from fds.sdk.GIPS.model.fact_set_protobuf_stach_v3_table_types_error_types_source_types_cell import FactSetProtobufStachV3TableTypesErrorTypesSourceTypesCell
from fds.sdk.GIPS.model.fact_set_protobuf_stach_v3_table_types_error_types_source_types_column import FactSetProtobufStachV3TableTypesErrorTypesSourceTypesColumn
from fds.sdk.GIPS.model.fact_set_protobuf_stach_v3_table_types_error_types_source_types_row import FactSetProtobufStachV3TableTypesErrorTypesSourceTypesRow
from fds.sdk.GIPS.model.fact_set_protobuf_stach_v3_table_types_format_result import FactSetProtobufStachV3TableTypesFormatResult
from fds.sdk.GIPS.model.fact_set_protobuf_stach_v3_table_types_group_result import FactSetProtobufStachV3TableTypesGroupResult
from fds.sdk.GIPS.model.fact_set_protobuf_stach_v3_table_types_group_result_types_aggregate_value import FactSetProtobufStachV3TableTypesGroupResultTypesAggregateValue
from fds.sdk.GIPS.model.fact_set_protobuf_stach_v3_table_types_group_result_types_aggregate_value_types_function import FactSetProtobufStachV3TableTypesGroupResultTypesAggregateValueTypesFunction
from fds.sdk.GIPS.model.fact_set_protobuf_stach_v3_table_types_pagination import FactSetProtobufStachV3TableTypesPagination
from fds.sdk.GIPS.model.fact_set_protobuf_stach_v3_table_types_pagination_type_oneof_case import FactSetProtobufStachV3TableTypesPaginationTypeOneofCase
from fds.sdk.GIPS.model.fact_set_protobuf_stach_v3_table_types_pagination_types_cursor import FactSetProtobufStachV3TableTypesPaginationTypesCursor
from fds.sdk.GIPS.model.fact_set_protobuf_stach_v3_table_types_pagination_types_offset import FactSetProtobufStachV3TableTypesPaginationTypesOffset
from fds.sdk.GIPS.model.fact_set_protobuf_stach_v3_table_types_split_result import FactSetProtobufStachV3TableTypesSplitResult
from fds.sdk.GIPS.model.fact_set_protobuf_stach_v3_table_view import FactSetProtobufStachV3TableView
from fds.sdk.GIPS.model.fact_set_protobuf_stach_v3_table_view_types_aggregate import FactSetProtobufStachV3TableViewTypesAggregate
from fds.sdk.GIPS.model.fact_set_protobuf_stach_v3_table_view_types_aggregate_types_function import FactSetProtobufStachV3TableViewTypesAggregateTypesFunction
from fds.sdk.GIPS.model.fact_set_protobuf_stach_v3_table_view_types_collapsed_column import FactSetProtobufStachV3TableViewTypesCollapsedColumn
from fds.sdk.GIPS.model.fact_set_protobuf_stach_v3_table_view_types_format import FactSetProtobufStachV3TableViewTypesFormat
from fds.sdk.GIPS.model.fact_set_protobuf_stach_v3_table_view_types_format_types_format_string import FactSetProtobufStachV3TableViewTypesFormatTypesFormatString
from fds.sdk.GIPS.model.fact_set_protobuf_stach_v3_table_view_types_format_types_format_string_type_oneof_case import FactSetProtobufStachV3TableViewTypesFormatTypesFormatStringTypeOneofCase
from fds.sdk.GIPS.model.fact_set_protobuf_stach_v3_table_view_types_format_types_single_value_format_string import FactSetProtobufStachV3TableViewTypesFormatTypesSingleValueFormatString
from fds.sdk.GIPS.model.fact_set_protobuf_stach_v3_table_view_types_group import FactSetProtobufStachV3TableViewTypesGroup
from fds.sdk.GIPS.model.fact_set_protobuf_stach_v3_table_view_types_horizontal_alignment import FactSetProtobufStachV3TableViewTypesHorizontalAlignment
from fds.sdk.GIPS.model.fact_set_protobuf_stach_v3_table_view_types_horizontal_alignment_types_alignment import FactSetProtobufStachV3TableViewTypesHorizontalAlignmentTypesAlignment
from fds.sdk.GIPS.model.fact_set_protobuf_stach_v3_table_view_types_split import FactSetProtobufStachV3TableViewTypesSplit
from fds.sdk.GIPS.model.fact_set_protobuf_stach_v3_views_types_view import FactSetProtobufStachV3ViewsTypesView
from fds.sdk.GIPS.model.fact_set_protobuf_stach_v3_views_types_view_type_oneof_case import FactSetProtobufStachV3ViewsTypesViewTypeOneofCase
from fds.sdk.GIPS.model.gips_calculation_parameters import GIPSCalculationParameters
from fds.sdk.GIPS.model.gips_calculation_parameters_root import GIPSCalculationParametersRoot
from fds.sdk.GIPS.model.gips_views import GIPSViews
from fds.sdk.GIPS.model.gips_views_root import GIPSViewsRoot
from fds.sdk.GIPS.model.google_protobuf_well_known_types_list_value import GoogleProtobufWellKnownTypesListValue
from fds.sdk.GIPS.model.google_protobuf_well_known_types_null_value import GoogleProtobufWellKnownTypesNullValue
from fds.sdk.GIPS.model.google_protobuf_well_known_types_struct import GoogleProtobufWellKnownTypesStruct
from fds.sdk.GIPS.model.google_protobuf_well_known_types_value import GoogleProtobufWellKnownTypesValue
from fds.sdk.GIPS.model.google_protobuf_well_known_types_value_kind_oneof_case import GoogleProtobufWellKnownTypesValueKindOneofCase
from fds.sdk.GIPS.model.pagination_info import PaginationInfo
from fds.sdk.GIPS.model.pagination_meta import PaginationMeta
